@@ -1,4 +1,4 @@
-// $Id: /mirror/openjsan/users/theory/Test.Simple/trunk/lib/Test/Harness/Browser.js 1642 2008-07-03T08:20:55.797043Z ingy  $
+// $Id: /mirror/openjsan/users/theory/Test.Simple/trunk/lib/Test/Harness/Browser.js 1950 2008-08-20T06:40:51.750920Z ingy  $
 
 /*global JSAN, Test, ActiveXObject */
 
@@ -74,7 +74,7 @@ if (window.parent != window &&
         this.includes.push('');
     };
 
-    Test.Harness.Browser.VERSION = '0.24';
+    Test.Harness.Browser.VERSION = '0.27';
 
     Test.Harness.Browser.runTests = function () {
         var harness = new Test.Harness.Browser();
@@ -109,11 +109,19 @@ if (window.parent != window &&
         var node = document.createElement('pre');
         node.setAttribute('id', 'output');
         document.body.appendChild(node);
+        fixoutput = function(node) {
+            // Trailing space added and replaced to work around yet another
+            // Safari bug.
+            node.innerHTML = node.innerHTML.replace(
+                / ?(\w[\w\.\-]+?\w)(?=\.\.\.)/m, '<a href="$1">$1</a>'
+            ) + ' ';
+        };
         return {
             pass: function (msg) {
                 node.appendChild(document.createTextNode(msg));
                 window.scrollTo(0, document.body.offsetHeight
                                 || document.body.scrollHeight);
+                fixoutput(node);
             },
             fail: function (msg) {
                 var red = document.createElement('span');
