@@ -1,4 +1,4 @@
-// $Id: /mirror/openjsan/users/theory/Test.Simple/trunk/lib/Test/Builder.js 1642 2008-07-03T08:20:55.797043Z ingy  $
+// $Id: /mirror/openjsan/users/theory/Test.Simple/trunk/lib/Test/Builder.js 1950 2008-08-20T06:40:51.750920Z ingy  $
 
 /*global JSAN, Test, WScript, _global */
 
@@ -36,7 +36,7 @@ Test.Builder.globalScope = typeof JSAN != 'undefined'
       ? _global
       : this;
 
-Test.Builder.VERSION = '0.25';
+Test.Builder.VERSION = '0.27';
 Test.Builder.Instances = [];
 Test.Builder.lineEndingRx = /\r?\n|\r/g;
 Test.Builder.StringOps = {
@@ -406,8 +406,8 @@ Test.Builder.prototype._isDiag = function (got, op, expect) {
     }
 
     return this.diag(
-        "         got: " + args[0] + Test.Builder.LF +
-        "    expected: " + args[1] + Test.Builder.LF
+        "        have: " + args[0] + Test.Builder.LF +
+        "        want: " + args[1] + Test.Builder.LF
     );
 };
 
